#!/usr/bin/env python3
#coding=utf-8

import logging

class LogFormat:
    '''
    预定义日志格式\n
    logFilePath: 存放日志文件的路径\n
    ConsoleLogLevel、FileLogLevel: 指定控制台和文件日志等级\n
    LogLevel={ DEBUG:10, INFO:20, WARNING:30, ERROR:40, CRITICAL:50 }\n
    Formatter: 重写Formatter时指定, 默认为None即使用预定义格式\n
    '''
    __formatter = logging.Formatter('%(asctime)s %(levelname)s  %(message)s')
    def __init__(self, logFilePath, ConsoleLogLevel=logging.DEBUG, FileLogLevel=logging.DEBUG, Formatter=None):
        Formatter = self.__formatter if Formatter == None else logging.Formatter(Formatter)
        self.logger = logging.getLogger(logFilePath)
        self.logger.setLevel(logging.DEBUG)
        '''define file handler'''
        __file_handler = logging.FileHandler(logFilePath)
        __file_handler.setLevel(FileLogLevel)
        __file_handler.setFormatter(Formatter)   
        '''define console handler'''
        __console_handler = logging.StreamHandler()
        __console_handler.setLevel(ConsoleLogLevel)
        __console_handler.setFormatter(Formatter)
        '''binding handler'''
        self.logger.addHandler(__file_handler)
        self.logger.addHandler(__console_handler)

    def debug(self, message):
        '''level = 10'''
        self.logger.debug(message)

    def info(self, message):
        '''level = 20'''
        self.logger.info(message)

    def warning(self, message):
        '''level = 30'''
        self.logger.warning(message)

    def error(self, message):
        '''level = 40'''
        self.logger.error(message)

    def critical(self, message):
        '''level = 50'''
        self.logger.critical(message)



#!/usr/bin/env python3
#coding=utf-8

from fabric.api import put,sudo
from os.path import dirname,basename


class FabricCommon():
    '''
    Fabric开发过程中常用的方法
    '''
    _PythonVersion = 3
    _FabricVersion = 3
    def __CreateSalt(self):
        ''' 假装生成了一个唯一字符串 '''
        from random import sample
        from string import ascii_letters,digits
        salt = ''.join(sample(ascii_letters + digits,20))
        return salt

    def __changeModeOwner(self,dest,mode,owner,group):
        ''' 修改文件owner、group、mode '''
        sudo('chown %s:%s %s && chmod %s %s' % owner,group,dest,mode,dest)

    def files(self,src,dest,**kwargs):
        ''' 封装一个 fabric.api.put 并修改文件属性'''
        owner = kwargs['owner'] if kwargs['owner'] != None else 'root'
        group = kwargs['group'] if kwargs['group'] != None else 'root'
        mode = kwargs['mode'] if kwargs['mode'] != None else 0o644
        put(local_path=src,remote_path=dest,mode=mode, use_sudo=True)
        self.__changeModeOwner(dest,mode,owner,group)

    def readConfigFiles(self,ConfigFilePath):
        ''' 读取.conf或.ini文件,返回一个字典 '''
        from configparser import ConfigParser
        conf = ConfigParser()
        conf.read(ConfigFilePath)
        VarsDict = {}
        for section in conf.sections():
            for option in conf.options(section):
                Vars[option.upper()] = conf.get(section,option)
        return VarsDict
    def readYamlFile(self,YamlFilePath):
        ''' 读取Yaml文件,返回一个字典 '''
        from yaml import load,FullLoader
        with open(YamlFilePath,'r') as conf:
            return load(conf, Loader=FullLoader)

    def templates(self,Vars,src,dest,**kwargs):
        '''
        使用模版创建新文件并发送到远程主机,需要一个字典替换变量
        '''
        owner = kwargs['owner'] if kwargs['owner'] != None else 'root'
        group = kwargs['group'] if kwargs['group'] != None else 'root'
        mode = kwargs['mode'] if kwargs['mode'] != None else 0o644
        from jinja2 import Environment, FileSystemLoader
        environment = Environment(loader=FileSystemLoader(dirname(src)))
        content = environment.get_template(basename(src)).render(Vars)
        salt = self.__CreateSalt()
        with open('/tmp/%s' % salt,'w') as temp:
            temp.write(content)
        put(local_path='/tmp/%s' % salt, remote_path=dest,use_sudo=True)
        self.__changeModeOwner(dest,mode,owner,group)





#!/usr/bin/env python
# coding=utf-8

from setuptools import setup, find_packages

setup(
    name='lunuan',
    version='0.1.2',
    description=('Python开发中常用的类'),
    long_description=(
        'Python开发中常用的类'
    ),
    author='huaxing',
    author_email='huaxing@lunuan.com.cn',
    maintainer='huaxing',
    maintainer_email='huaxing@lunuan.com.cn',
    license='BSD License',
    packages=find_packages(),
    platforms=["all"],
    url=' ',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)
